.. :changelog:

History
-------

0.4 2013-10-17
++++++++++++++
* Fixed default mode always closing FDs.
  https://github.com/nbargnesi/lazarus/issues/5

0.3 2013-10-16
++++++++++++++

* Added ability to specify restart command
* Added ability to cancel the restart

0.1 2013-10-15
++++++++++++++

* First functional release.

